@@ -25,6 +25,7 @@
 #include "grn_encoding.h"
 #include "grn_hash.h"
 #include "grn_ii.h"
+#include "grn_language_model.hpp"
 #include "grn_pat.h"
 #include "grn_index_column.h"
 #include "grn_proc.h"
@@ -109,7 +110,7 @@ int grn_lock_timeout = GRN_LOCK_TIMEOUT;
 int grn_uyield_count = 0;
 #endif
 
-static grn_bool grn_ctx_per_db = GRN_FALSE;
+static bool grn_ctx_per_db = false;
 static bool grn_back_trace_enable = true;
 static int32_t grn_n_workers_default = 0;
 
@@ -120,7 +121,7 @@ grn_init_from_env(void)
     char grn_ctx_per_db_env[GRN_ENV_BUFFER_SIZE];
     grn_getenv("GRN_CTX_PER_DB", grn_ctx_per_db_env, GRN_ENV_BUFFER_SIZE);
     if (grn_ctx_per_db_env[0] && strcmp(grn_ctx_per_db_env, "yes") == 0) {
-      grn_ctx_per_db = GRN_TRUE;
+      grn_ctx_per_db = true;
     }
   }
 
@@ -161,6 +162,7 @@ grn_init_from_env(void)
   grn_io_init_from_env();
   grn_ii_init_from_env();
   grn_ja_init_from_env();
+  grn::language_model::init_from_env();
   grn_db_init_from_env();
   grn_expr_init_from_env();
   grn_index_column_init_from_env();
@@ -196,6 +198,7 @@ grn_fin_external_libraries(void)
 #ifdef GRN_WITH_BLOSC
   blosc2_destroy();
 #endif
+  grn::language_model::fin_external_libraries();
 }
 
 void
@@ -407,7 +410,9 @@ grn_ctx_impl_init(grn_ctx *ctx)
   ctx->impl->curr_expr = NULL;
   GRN_TEXT_INIT(&ctx->impl->current_request_id, 0);
   ctx->impl->current_request_timer_id = NULL;
-  ctx->impl->parser = NULL;
+  /* grn_obj * isn't void * but sizeof(grn_obj *) and sizeof(void *)
+   * is same. So we reuse GRN_PVECTOR here. */
+  GRN_PTR_INIT(&(ctx->impl->expr_parsers), GRN_OBJ_VECTOR, GRN_ID_NIL);
 
   GRN_TEXT_INIT(&ctx->impl->output.names, GRN_OBJ_VECTOR);
   GRN_UINT32_INIT(&ctx->impl->output.levels, GRN_OBJ_VECTOR);
@@ -592,6 +597,39 @@ grn_ctx_release_child(grn_ctx *ctx, grn_ctx *child_ctx)
   return ctx->rc;
 }
 
+void *
+grn_ctx_expr_parser_pull(grn_ctx *ctx)
+{
+  void *parser = NULL;
+  if (GRN_PTR_VECTOR_SIZE(&(ctx->impl->expr_parsers)) == 0) {
+    parser = grn_expr_parser_open(ctx);
+  } else {
+    grn_obj *value;
+    GRN_PTR_POP(&(ctx->impl->expr_parsers), value);
+    parser = reinterpret_cast<void *>(value);
+  }
+  return parser;
+}
+
+grn_rc
+grn_ctx_expr_parser_release(grn_ctx *ctx, void *parser)
+{
+  GRN_PTR_PUT(ctx, &(ctx->impl->expr_parsers), parser);
+  return ctx->rc;
+}
+
+grn_rc
+grn_ctx_expr_parsers_clear(grn_ctx *ctx)
+{
+  while (GRN_PTR_VECTOR_SIZE(&(ctx->impl->expr_parsers)) > 0) {
+    grn_obj *value;
+    GRN_PTR_POP(&(ctx->impl->expr_parsers), value);
+    auto expr_parser = reinterpret_cast<void *>(value);
+    grn_expr_parser_close(ctx, expr_parser);
+  }
+  return ctx->rc;
+}
+
 grn_rc
 grn_ctx_set_progress_callback(grn_ctx *ctx,
                               grn_progress_callback_func func,
@@ -768,9 +806,8 @@ grn_ctx_impl_fin(grn_ctx *ctx)
   grn_ctx_impl_mrb_fin(ctx);
   GRN_OBJ_FIN(ctx, &(ctx->impl->slow_log.start_times));
   grn_ctx_loader_clear(ctx);
-  if (ctx->impl->parser) {
-    grn_expr_parser_close(ctx);
-  }
+  grn_ctx_expr_parsers_clear(ctx);
+  GRN_OBJ_FIN(ctx, &(ctx->impl->expr_parsers));
   GRN_OBJ_FIN(ctx, &ctx->impl->current_request_id);
   if (ctx->impl->values) {
 #ifndef GRN_WITH_MEMORY_DEBUG
@@ -1734,7 +1771,7 @@ get_n_workers(grn_ctx *ctx, const char *p, const char *pe)
 #define HTTP_QUERY_PAIR_DELIMITER   "="
 #define HTTP_QUERY_PAIRS_DELIMITERS "&;"
 
-static grn_inline int
+static inline int
 command_proc_p(grn_obj *expr)
 {
   return (expr->header.type == GRN_PROC &&
@@ -1803,9 +1840,9 @@ grn_ctx_qe_exec_uri(grn_ctx *ctx, const char *path, uint32_t path_len)
           p = grn_text_cgidec(ctx, &buf, p, e, HTTP_QUERY_PAIRS_DELIMITERS);
           if (GRN_TEXT_LEN(&buf) == strlen("yes") &&
               !memcmp(GRN_TEXT_VALUE(&buf), "yes", GRN_TEXT_LEN(&buf))) {
-            ctx->impl->output.is_pretty = GRN_TRUE;
+            ctx->impl->output.is_pretty = true;
           } else {
-            ctx->impl->output.is_pretty = GRN_FALSE;
+            ctx->impl->output.is_pretty = false;
           }
         } else if (l == OUTPUT_TRACE_LOG_LEN &&
                    !memcmp(v, OUTPUT_TRACE_LOG, OUTPUT_TRACE_LOG_LEN)) {
@@ -1929,9 +1966,9 @@ grn_ctx_qe_exec(grn_ctx *ctx, const char *str, uint32_t str_len)
           p = grn_text_unesc_tok(ctx, &buf, p, e, &tok_type);
           if (GRN_TEXT_LEN(&buf) == strlen("yes") &&
               !memcmp(GRN_TEXT_VALUE(&buf), "yes", GRN_TEXT_LEN(&buf))) {
-            ctx->impl->output.is_pretty = GRN_TRUE;
+            ctx->impl->output.is_pretty = true;
           } else {
-            ctx->impl->output.is_pretty = GRN_FALSE;
+            ctx->impl->output.is_pretty = false;
           }
         } else if (l == OUTPUT_TRACE_LOG_LEN &&
                    !memcmp(v, OUTPUT_TRACE_LOG, OUTPUT_TRACE_LOG_LEN)) {
@@ -2111,7 +2148,7 @@ grn_ctx_send(grn_ctx *ctx, const char *str, unsigned int str_len, int flags)
         GRN_BULK_REWIND(&(ctx->impl->output.levels));
         ctx->impl->output.type = GRN_CONTENT_JSON;
         ctx->impl->output.mime_type = "application/json";
-        ctx->impl->output.is_pretty = GRN_FALSE;
+        ctx->impl->output.is_pretty = false;
         grn_timeval_now(ctx, &ctx->impl->tv);
         GRN_QUERY_LOG(ctx, GRN_QUERY_LOG_COMMAND, ">", "%.*s", str_len, str);
         if (str_len && *str == '/') {
@@ -2177,14 +2214,14 @@ grn_ctx_recv(grn_ctx *ctx, char **str, unsigned int *str_len, int *flags)
   *flags = 0;
 
   if (ctx->stat == GRN_CTX_QUIT) {
-    grn_bool have_buffer = GRN_FALSE;
+    bool have_buffer = false;
 
     if (ctx->impl && !ctx->impl->com &&
         GRN_TEXT_LEN(ctx->impl->output.buf) > 0) {
-      have_buffer = GRN_TRUE;
+      have_buffer = true;
     }
 
-    *flags |= GRN_CTX_QUIT;
+    *flags = GRN_CTX_QUIT;
     if (!have_buffer) {
       *str = NULL;
       *str_len = 0;
@@ -2205,14 +2242,15 @@ grn_ctx_recv(grn_ctx *ctx, char **str, unsigned int *str_len, int *flags)
         *str_len = (unsigned int)GRN_BULK_VSIZE(ctx->impl->output.buf);
         if (header.flags & GRN_CTX_QUIT) {
           ctx->stat = GRN_CTX_QUIT;
-          *flags |= GRN_CTX_QUIT;
+          *flags = GRN_CTX_QUIT;
         } else {
           if (!(header.flags & GRN_CTX_TAIL)) {
-            *flags |= GRN_CTX_MORE;
+            *flags = GRN_CTX_MORE;
           }
         }
         ctx->impl->output.type = static_cast<grn_content_type>(header.qtype);
-        ctx->rc = static_cast<grn_rc>(ntohs(header.status));
+        ctx->rc =
+          static_cast<grn_rc>(static_cast<int16_t>(ntohs(header.status)));
         ctx->errbuf[0] = '\0';
         ctx->errline = 0;
         ctx->errfile = NULL;
@@ -2221,10 +2259,8 @@ grn_ctx_recv(grn_ctx *ctx, char **str, unsigned int *str_len, int *flags)
       goto exit;
     } else {
       grn_obj *buf = ctx->impl->output.buf;
-      size_t head = 0;
-      size_t tail = GRN_BULK_VSIZE(buf);
-      *str = GRN_BULK_HEAD(buf) + head;
-      *str_len = (unsigned int)(tail - head);
+      *str = GRN_BULK_HEAD(buf);
+      *str_len = (unsigned int)GRN_BULK_VSIZE(buf);
       GRN_BULK_REWIND(ctx->impl->output.buf);
       goto exit;
     }
@@ -2747,6 +2783,20 @@ grn_ctx_output_obj(grn_ctx *ctx, grn_obj *value, grn_obj_format *format)
                  format);
 }
 
+void
+grn_ctx_output_result_set_open_metadata(grn_ctx *ctx,
+                                        grn_obj *result_set,
+                                        grn_obj_format *format,
+                                        uint32_t n_additional_elements)
+{
+  grn_output_result_set_open_metadata(ctx,
+                                      ctx->impl->output.buf,
+                                      ctx->impl->output.type,
+                                      result_set,
+                                      format,
+                                      n_additional_elements);
+}
+
 void
 grn_ctx_output_result_set_open(grn_ctx *ctx,
                                grn_obj *result_set,
