@@ -52,7 +52,7 @@ grn_error_init_from_env(void);
 void
 grn_error_cancel(grn_ctx *ctx);
 
-static grn_inline grn_rc
+static inline grn_rc
 grn_ctx_rc_propagate(grn_ctx *ctx, grn_rc rc)
 {
   if (rc != GRN_SUCCESS) {
@@ -61,7 +61,7 @@ grn_ctx_rc_propagate(grn_ctx *ctx, grn_rc rc)
   return ctx->rc;
 }
 
-GRN_API grn_bool
+GRN_API bool
 grn_ctx_impl_should_log(grn_ctx *ctx);
 GRN_API void
 grn_ctx_impl_set_current_error_message(grn_ctx *ctx);
@@ -73,7 +73,7 @@ grn_ctx_logv(grn_ctx *ctx, const char *fmt, va_list ap);
 GRN_API void
 grn_ctx_log_back_trace(grn_ctx *ctx, grn_log_level level);
 
-static grn_inline void
+static inline void
 grn_error_setv(grn_ctx *ctx,
                grn_log_level level,
                grn_rc rc,
@@ -111,7 +111,7 @@ grn_error_setv(grn_ctx *ctx,
   va_end(logger_putv_args);
 }
 
-static grn_inline void
+static inline void
 grn_error_set(grn_ctx *ctx,
               grn_log_level level,
               grn_rc rc,
@@ -120,7 +120,7 @@ grn_error_set(grn_ctx *ctx,
               const char *function,
               const char *format,
               ...) GRN_ATTRIBUTE_PRINTF(7);
-static grn_inline void
+static inline void
 grn_error_set(grn_ctx *ctx,
               grn_log_level level,
               grn_rc rc,
@@ -276,7 +276,7 @@ grn_error_set(grn_ctx *ctx,
     do {                                                                       \
       grn_rc rc;                                                               \
       int errno_keep = errno;                                                  \
-      grn_bool show_errno = GRN_FALSE;                                         \
+      bool show_errno = false;                                                 \
       const char *system_message;                                              \
       char user_message[USER_MESSAGE_SIZE];                                    \
       system_message = grn_strerror(errno);                                    \
@@ -381,7 +381,7 @@ grn_error_set(grn_ctx *ctx,
       /* case STRUNCATE : */                                                   \
       default:                                                                 \
         rc = GRN_UNKNOWN_ERROR;                                                \
-        show_errno = GRN_TRUE;                                                 \
+        show_errno = true;                                                     \
         break;                                                                 \
       }                                                                        \
       grn_snprintf(user_message,                                               \
@@ -405,7 +405,7 @@ grn_error_set(grn_ctx *ctx,
     do {                                                                       \
       grn_rc rc;                                                               \
       int errno_keep = errno;                                                  \
-      grn_bool show_errno = GRN_FALSE;                                         \
+      bool show_errno = false;                                                 \
       const char *system_message = grn_error_get_current_system_message();     \
       char user_message[USER_MESSAGE_SIZE];                                    \
       switch (errno_keep) {                                                    \
@@ -539,7 +539,7 @@ grn_error_set(grn_ctx *ctx,
         break;                                                                 \
       default:                                                                 \
         rc = GRN_UNKNOWN_ERROR;                                                \
-        show_errno = GRN_TRUE;                                                 \
+        show_errno = true;                                                     \
         break;                                                                 \
       }                                                                        \
       grn_snprintf(user_message,                                               \
