@@ -122,7 +122,7 @@ typedef struct {
   score_heap_node *nodes;
 } score_heap;
 
-static grn_inline score_heap *
+static inline score_heap *
 score_heap_open(grn_ctx *ctx, uint32_t max)
 {
   score_heap *h = GRN_PLUGIN_MALLOC(ctx, sizeof(score_heap));
@@ -137,7 +137,7 @@ score_heap_open(grn_ctx *ctx, uint32_t max)
   return h;
 }
 
-static grn_inline grn_bool
+static inline bool
 score_heap_push(grn_ctx *ctx, score_heap *h, grn_id id, uint32_t score)
 {
   uint32_t n, n2;
@@ -148,7 +148,7 @@ score_heap_push(grn_ctx *ctx, score_heap *h, grn_id id, uint32_t score)
     score_heap_node *nodes;
     nodes = GRN_PLUGIN_REALLOC(ctx, h->nodes, sizeof(score_heap) * max);
     if (!nodes) {
-      return GRN_FALSE;
+      return false;
     }
     h->limit = max;
     h->nodes = nodes;
@@ -163,10 +163,10 @@ score_heap_push(grn_ctx *ctx, score_heap *h, grn_id id, uint32_t score)
     h->nodes[n2] = node2;
     n = n2;
   }
-  return GRN_TRUE;
+  return true;
 }
 
-static grn_inline void
+static inline void
 score_heap_close(grn_ctx *ctx, score_heap *h)
 {
   GRN_PLUGIN_FREE(ctx, h->nodes);
